import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import MoleculeTab from './components/MoleculeTab';
import withStateActiveTab from './hoc/withStateActiveTab';
var BASE_CLASS = "sui-MoleculeTabs";
var CLASS_SCROLLER = BASE_CLASS + "-scroller";
var CLASS_CONTENT = BASE_CLASS + "-content";
var TYPES = {
  HORIZONTAL: 'horizontal',
  VERTICAL: 'vertical',
  FULLWIDTH: 'fullWidth'
};
var VARIANTS = {
  HIGHLIGHTED: 'highlighted',
  CLASSIC: 'classic'
};

var MoleculeTabs = function MoleculeTabs(_ref) {
  var variant = _ref.variant,
      type = _ref.type,
      children = _ref.children,
      onChange = _ref.onChange;
  var CLASS_VARIANT = BASE_CLASS + "--" + variant;
  var CLASS_TYPE = BASE_CLASS + "--" + type;
  var className = cx(BASE_CLASS, CLASS_VARIANT, CLASS_TYPE);
  var extendedChildren = React.Children.map(children, function (child, index) {
    var numTab = index + 1;
    return React.cloneElement(child, {
      onChange: onChange,
      numTab: numTab
    });
  });
  var activeTabContent = React.Children.toArray(children).reduce(function (activeContent, child) {
    var _child$props = child.props,
        childrenChild = _child$props.children,
        active = _child$props.active;
    return active ? childrenChild : activeContent;
  }, null);
  return /*#__PURE__*/React.createElement("div", {
    className: className
  }, /*#__PURE__*/React.createElement("ul", {
    className: CLASS_SCROLLER
  }, extendedChildren), /*#__PURE__*/React.createElement("div", {
    className: CLASS_CONTENT
  }, activeTabContent));
};

MoleculeTabs.displayName = 'MoleculeTabs';
MoleculeTabs.defaultProps = {
  variant: VARIANTS.CLASSIC,
  type: TYPES.HORIZONTAL,
  onChange: function onChange() {}
};
export default withStateActiveTab(MoleculeTabs);
export { MoleculeTabs, MoleculeTab, TYPES as moleculeTabsTypes, VARIANTS as moleculeTabsVariants };